@@ -1,8 +1,8 @@
 ### the gnu tar specification:
-### http://www.gnu.org/software/tar/manual/tar.html
+### https://www.gnu.org/software/tar/manual/tar.html
 ###
 ### and the pax format spec, which tar derives from:
-### http://www.opengroup.org/onlinepubs/007904975/utilities/pax.html
+### https://www.opengroup.org/onlinepubs/007904975/utilities/pax.html
 
 package Archive::Tar;
 require 5.005_03;
@@ -24,6 +24,7 @@ use strict;
 use vars qw[$DEBUG $error $VERSION $WARN $FOLLOW_SYMLINK $CHOWN $CHMOD
             $DO_NOT_USE_PREFIX $HAS_PERLIO $HAS_IO_STRING $SAME_PERMISSIONS
             $INSECURE_EXTRACT_MODE $ZERO_PAD_NUMBERS @ISA @EXPORT $RESOLVE_SYMLINK
+            $EXTRACT_BLOCK_SIZE
          ];
 
 @ISA                    = qw[Exporter];
@@ -31,7 +32,7 @@ use vars qw[$DEBUG $error $VERSION $WARN $FOLLOW_SYMLINK $CHOWN $CHMOD
 $DEBUG                  = 0;
 $WARN                   = 1;
 $FOLLOW_SYMLINK         = 0;
-$VERSION                = "2.34";
+$VERSION                = "3.00";
 $CHOWN                  = 1;
 $CHMOD                  = 1;
 $SAME_PERMISSIONS       = $> == 0 ? 1 : 0;
@@ -39,6 +40,7 @@ $DO_NOT_USE_PREFIX      = 0;
 $INSECURE_EXTRACT_MODE  = 0;
 $ZERO_PAD_NUMBERS       = 0;
 $RESOLVE_SYMLINK        = $ENV{'PERL5_AT_RESOLVE_SYMLINK'} || 'speed';
+$EXTRACT_BLOCK_SIZE     = 1024 * 1024 * 1024;
 
 BEGIN {
     use Config;
@@ -48,7 +50,7 @@ BEGIN {
     ### switch between perlio and IO::String
     $HAS_IO_STRING = eval {
         require IO::String;
-        import IO::String;
+        IO::String->import;
         1;
     } || 0;
 }
@@ -423,7 +425,7 @@ sub _read_tar {
         }
 
         ### ignore labels:
-        ### http://www.gnu.org/software/tar/manual/html_chapter/Media.html#SEC159
+        ### https://www.gnu.org/software/tar/manual/html_chapter/Media.html#SEC159
         next if $entry->is_label;
 
         if( length $entry->type and ($entry->is_file || $entry->is_longlink) ) {
@@ -894,10 +896,18 @@ sub _extract_file {
 
         if( $entry->size ) {
             binmode $fh;
-            syswrite $fh, $entry->data or (
-                $self->_error( qq[Could not write data to '$full'] ),
-                return
-            );
+            my $offset = 0;
+            my $content = $entry->get_content_by_ref();
+            while ($offset < $entry->size) {
+                my $written
+                    = syswrite $fh, $$content, $EXTRACT_BLOCK_SIZE, $offset;
+                if (defined $written) {
+                    $offset += $written;
+                } else {
+                    $self->_error( qq[Could not write data to '$full': $!] );
+                    return;
+                }
+            }
         }
 
         close $fh or (
@@ -918,7 +928,7 @@ sub _extract_file {
     }
 
     if( $CHOWN && CAN_CHOWN->() and not -l $full ) {
-        chown $entry->uid, $entry->gid, $full or
+        CORE::chown( $entry->uid, $entry->gid, $full ) or
             $self->_error( qq[Could not set uid/gid on '$full'] );
     }
 
@@ -929,7 +939,7 @@ sub _extract_file {
         unless ($SAME_PERMISSIONS) {
             $mode &= ~(oct(7000) | umask);
         }
-        chmod $mode, $full or
+        CORE::chmod( $mode, $full ) or
             $self->_error( qq[Could not chown '$full' to ] . $entry->mode );
     }
 
@@ -2163,6 +2173,14 @@ numbers. Added for compatibility with C<busybox> implementations.
 
 		It won't work for terminal, pipe or sockets or every non seekable source.
 
+=head2 $Archive::Tar::EXTRACT_BLOCK_SIZE
+
+This variable holds an integer with the block size that should be used when
+writing files during extraction. It defaults to 1 GiB. Please note that this
+cannot be arbitrarily large since some operating systems limit the number of
+bytes that can be written in one call to C<write(2)>, so if this is too large,
+extraction may fail with an error.
+
 =cut
 
 =head1 FAQ
@@ -2284,7 +2302,7 @@ write a C<.tar.Z> file
     use Archive::Tar;
     use IO::File;
 
-    my $fh = new IO::File "| compress -c >$filename";
+    my $fh = IO::File->new( "| compress -c >$filename" );
     my $tar = Archive::Tar->new();
     ...
     $tar->write($fh);
@@ -2396,22 +2414,11 @@ to an uploaded file, which might be a compressed archive.
 
 =item The GNU tar specification
 
-C<http://www.gnu.org/software/tar/manual/tar.html>
+L<https://www.gnu.org/software/tar/manual/tar.html>
 
 =item The PAX format specification
 
-The specification which tar derives from; C< http://www.opengroup.org/onlinepubs/007904975/utilities/pax.html>
-
-=item A comparison of GNU and POSIX tar standards; C<http://www.delorie.com/gnu/docs/tar/tar_114.html>
-
-=item GNU tar intends to switch to POSIX compatibility
-
-GNU Tar authors have expressed their intention to become completely
-POSIX-compatible; C<http://www.gnu.org/software/tar/manual/html_node/Formats.html>
-
-=item A Comparison between various tar implementations
-
-Lists known issues and incompatibilities; C<http://gd.tuwien.ac.at/utils/archivers/star/README.otherbugs>
+The specification which tar derives from; L<https://pubs.opengroup.org/onlinepubs/007904975/utilities/pax.html>
 
 =back
 
